@@ -1,4 +1,4 @@
-/* writetext.c - Test wether a .text sections can be written
+/* writetext.c - Test whether a .text sections can be written
  *
  * Copyright (c)2003 by Peter Busser <peter@adamantix.org>
  * This file has been released under the GNU Public Licence version 2 or later
@@ -12,7 +12,7 @@
 #include <sys/mman.h>
 #include "body.h"
 
-char *testname = "Writable text segments                   ";
+const char testname[] = "Writable text segments                   ";
 
 extern int shlibtest( void );
 
@@ -24,7 +24,7 @@ static void sigsegv( int sig )
 
 void doit( void )
 {
-	char *buf;
+	volatile char *buf;
 	char c;
 
 	buf = (char*)shlibtest;
@@ -48,9 +48,9 @@ void doit( void )
 	do_mprotect( buf, 4096, PROT_READ|PROT_WRITE|PROT_EXEC );
 
 	/* Try to write something */
+	/* gcc 4.5 optimized this out if buf wasn't volatile */
 	*buf = 'X';
 
 	/* It worked when the function returns */
 	itworked();
 }
-
